#!/usr/bin/env python
# -*- coding: utf-8 -*-

__version__ = '1.3.0'  #: the working version
__release__ = '1.0.0' #: the release version

from ._app import configure_api_key, check_ip, check_cidr, report_ip